<?php
/* Customize Appearance Options */
if ( !function_exists( 'blake_von_hauer_customizeAppearance' ) ) {
	function blake_von_hauer_customizeAppearance( $wp_customize ) {

		/* Custom Text Area Control in Customizer */
		class blake_von_hauer_customTextAreaControl extends WP_Customize_Control {

			public $type = 'textarea';

			public function render_content() { ?>
				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<textarea rows="8" style="width: 100%; resize: none;" <?php esc_url( $this->link() ); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
				</label>
			<?php }

		}
		/* */

		/* Font Selector */
		class blake_von_hauer_font_selector extends WP_Customize_Control {

				public $type = 'select';

				public function render_content() { ?>

					<label>
						<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
						<span class="customize-control-description"><?php echo wp_kses_post( $this->description ); ?></span>
						<select <?php $this->link(); ?>>
	                    	<?php
							foreach ( blake_von_hauer_font_labels() as $key => $val ) {
								$add_underscore = str_replace( ' ', '_', $key ); ?>
								<option value="<?php echo esc_attr( $add_underscore ); ?>" <?php if( $this->value() == $add_underscore ) echo 'selected="selected"'; ?>><?php echo esc_attr( $key ); ?></option>
							<?php } ?>
						</select>
					</label>

				<?php }

		}
		/* */

		/* BRNHMBX Font Switcher */
		class blake_von_hauer_FontSwitcher extends WP_Customize_Control {

			public $type = 'select';

			public function render_content() { ?>

				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<div style="margin-bottom: 10px;"><em><?php echo esc_html( $this->description ); ?></em></div>
					<select <?php $this->link(); ?> style="width: 100%;">
						<option value="blake-von-hauer-font-1" <?php if( $this->value() == 'blake-von-hauer-font-1' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Primary Font' ); ?></option>
						<option value="blake-von-hauer-font-2" <?php if( $this->value() == 'blake-von-hauer-font-2' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Secondary Font' ); ?></option>
						<option value="blake-von-hauer-font-3" <?php if( $this->value() == 'blake-von-hauer-font-3' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Tertiary Font' ); ?></option>
					</select>
				</label>

			<?php }

		}
		/* */

		/* BRNHMBX Banner Placement */
		class blake_von_hauer_BannerPlacement extends WP_Customize_Control {

			public $type = 'select';

			public function render_content() { ?>

				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<div style="margin-bottom: 10px;"><em><?php echo esc_html( $this->description ); ?></em></div>
					<select <?php $this->link(); ?> style="width: 100%;">
						<option value="hidden" <?php if( $this->value() == 'hidden' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Hidden' ); ?></option>
						<option value="below-header" <?php if( $this->value() == 'below-header' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Below Header' ); ?></option>
						<option value="above-upper-widgets" <?php if( $this->value() == 'above-upper-widgets' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Above Upper Widgets' ); ?></option>
						<option value="below-upper-widgets" <?php if( $this->value() == 'below-upper-widgets' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Below Upper Widgets' ); ?></option>
						<option value="above-blog-posts" <?php if( $this->value() == 'above-blog-posts' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Above Blog Posts' ); ?></option>
						<option value="after-first-post" <?php if( $this->value() == 'after-first-post' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'After First Post' ); ?></option>
						<option value="below-blog-posts" <?php if( $this->value() == 'below-blog-posts' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Below Blog Posts' ); ?></option>
						<option value="below-home-widgets" <?php if( $this->value() == 'below-home-widgets' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Below Blog Homepage Widgets' ); ?></option>
						<option value="above-post" <?php if( $this->value() == 'above-post' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Post Pages (Above the Post)' ); ?></option>
						<option value="below-post" <?php if( $this->value() == 'below-post' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Post Pages (Below the Post)' ); ?></option>
						<option value="below-post-comments" <?php if( $this->value() == 'below-post-comments' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Post Pages (Below Post Comments)' ); ?></option>
						<option value="above-page" <?php if( $this->value() == 'above-page' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Pages (Above the Page)' ); ?></option>
						<option value="below-page" <?php if( $this->value() == 'below-page' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Pages (Below the Page)' ); ?></option>
						<option value="below-page-comments" <?php if( $this->value() == 'below-page-comments' ) echo 'selected="selected"'; ?>><?php echo esc_html( 'Pages (Below Page Comments)' ); ?></option>
					</select>
				</label>

			<?php }

		}
		/* */

		/* Sanitizers */
		function blake_von_hauer_get_font_list() {
			$font_list = array();
			foreach ( blake_von_hauer_font_labels() as $key => $val ) {
				$add_underscore = str_replace( ' ', '_', $key );
				$font_list[] = esc_attr( $add_underscore );
			}
			return $font_list;
		}

		function blake_von_hauer_sanitize_select( $input ) {
			$current_font_list = blake_von_hauer_get_font_list();
	    return ( in_array( $input, $current_font_list ) ? $input : 'null' );
		}

		function blake_von_hauer_get_banner_positions() {
			if ( function_exists( 'blake_von_hauer_banner_positions' ) ) {
				$banner_position_list = array();
				foreach ( blake_von_hauer_banner_positions() as $key ) {
					$banner_position_list[] = esc_attr( $key );
				}
				return $banner_position_list;
			} else {
				return 0;
			}
		}

		function blake_von_hauer_sanitize_banner_positions( $input ) {
			if ( function_exists( 'blake_von_hauer_banner_positions' ) ) {
				$banner_positions = blake_von_hauer_get_banner_positions();
		    return ( in_array( $input, $banner_positions ) ? $input : 'null' );
			} else {
				return 0;
			}
		}

		function blake_von_hauer_get_font_switchers() {
			$banner_switchers_list = array();
			foreach ( blake_von_hauer_font_switchers() as $key ) {
				$banner_switchers_list[] = esc_attr( $key );
			}
			return $banner_switchers_list;
		}

		function blake_von_hauer_sanitize_font_switchers( $input ) {
			$banner_switchers = blake_von_hauer_get_font_switchers();
	    return ( in_array( $input, $banner_switchers ) ? $input : 'null' );
		}

		function blake_von_hauer_sanitize_file( $file, $setting ) {
	    $mimes = array(
	        'jpg|jpeg|jpe' => 'image/jpeg',
	        'gif'          => 'image/gif',
	        'png'          => 'image/png'
	    );
	    $file_ext = wp_check_filetype( $file, $mimes );
	    return ( $file_ext['ext'] ? $file : $setting->default );
	  }

		function blake_von_hauer_sanitize_null( $input ) {
			return 0;
		}

		function blake_von_hauer_sanitize_let_html( $input ) {
			return force_balance_tags( wp_kses_post( $input ) );
		}

		function blake_von_hauer_sanitize_checkbox( $input ) {
			if ( $input == 1 ) {
				return 1;
			} else {
				return '';
			}
		}

		function blake_von_hauer_sanitize_choices( $input, $setting ) {
			global $wp_customize;
			$control = $wp_customize->get_control( $setting->id );
			if ( array_key_exists( $input, $control->choices ) ) {
				return $input;
			} else {
				return $setting->default;
			}
		}

		function blake_von_hauer_sanitize_integer( $input ) {
			if( is_numeric( $input ) ) {
				return intval( $input );
			}
		}
		/* */

		/* Allowed HTML */
		$blake_von_hauer_allowed_html = array(
				'a' => array(
					'href' => array(),
					'target' => array(),
			),
			'span' => array(
				'class' => array(),
			),
			'br' => array(),
			'em' => array(),
			'strong' => array(),
			'hr' => array(),
		);
		/* */

		////////////////////////////////////////////////////
		/*/////////////////// SECTIONS ///////////////////*/
		////////////////////////////////////////////////////

		$wp_customize->add_section( 'blake_von_hauer_sectionFeaturedImage', array(
			'title' => esc_html__( '1. Featured Image Settings', 'blake-von-hauer' ),
			'priority' => 0,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionFonts', array(
			'title' => esc_html__( '2. Font Settings', 'blake-von-hauer' ),
			'priority' => 5,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionBackground', array(
			'title' => esc_html__( '3. Background & Colors', 'blake-von-hauer' ),
			'priority' => 10,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionHeader', array(
			'title' => esc_html__( '4. Header', 'blake-von-hauer' ),
			'priority' => 15,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionHomeWidgets', array(
			'title' => esc_html__( '5. Upper & Blog Homepage Widgets', 'blake-von-hauer' ),
			'priority' => 20,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionLayout', array(
			'title' => esc_html__( '6. Layout Options', 'blake-von-hauer' ),
			'priority' => 25,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionPostFormats', array(
			'title' => esc_html__( '7. Post Formats', 'blake-von-hauer' ),
			'priority' => 30,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionRP', array(
			'title' => esc_html__( '8. Related Posts & CTA Lines', 'blake-von-hauer' ),
			'priority' => 35,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionFooter', array(
			'title' => esc_html__( '9. Footer', 'blake-von-hauer' ),
			'priority' => 40,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionShowHide', array(
			'title' => esc_html__( '10. Show/Hide Elements', 'blake-von-hauer' ),
			'priority' => 45,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionSocial', array(
			'title' => esc_html__( '11. Social Accounts', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'Write the entire URL addresses.<br>Leave blank if not preferred.', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'priority' => 50,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionGoogleMaps', array(
			'title' => esc_html__( '12. Google Maps', 'blake-von-hauer' ),
			'priority' => 55,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionTranslation', array(
			'title' => esc_html__( '13. Translation', 'blake-von-hauer' ),
			'priority' => 60,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionBanner', array(
			'title' => esc_html__( '14. Banner Management', 'blake-von-hauer' ),
			'priority' => 65,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionSlider', array(
			'title' => esc_html__( '15. Slider Settings', 'blake-von-hauer' ),
			'priority' => 67,
		) );

		$wp_customize->add_section( 'blake_von_hauer_sectionCSS', array(
			'title' => esc_html__( 'Custom CSS', 'blake-von-hauer' ),
			'description' => esc_html__( 'Place your CSS code to override styles.', 'blake-von-hauer' ),
			'priority' => 70,
		) );

		////////////////////////////////////////////////////
		/*/////////////////// SETTINGS ///////////////////*/
		////////////////////////////////////////////////////

		/* Featured Image Settings */
		if ( !function_exists( 'wp_site_icon' ) ) {
			$wp_customize->add_setting( 'blake_von_hauer_upload_Favicon', array( 'sanitize_callback' => 'blake_von_hauer_sanitize_file' ) );
		}
		$wp_customize->add_setting( 'blake_von_hauer_explanation_1', array( 'default' => '0', 'sanitize_callback' => 'blake_von_hauer_sanitize_null' ) );
		$wp_customize->add_setting( 'blake_von_hauer_imageWidth', array( 'default' => 1040, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_imageHeight', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_thumbnailImageWidth', array( 'default' => 640, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_thumbnailImageHeight', array( 'default' => 960, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_thumbnailImageWidth_Hor', array( 'default' => 360, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_thumbnailImageHeight_Hor', array( 'default' => 540, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		/* */

		/* Font Settings */
		$wp_customize->add_setting( 'blake_von_hauer_font_1', array( 'default' => 'Playfair_Display', 'sanitize_callback' => 'blake_von_hauer_sanitize_select' ) );
		$wp_customize->add_setting( 'blake_von_hauer_font_1_bold', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_font_1_italic', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_font_2', array( 'default' => 'PT_Serif', 'sanitize_callback' => 'blake_von_hauer_sanitize_select' ) );
		$wp_customize->add_setting( 'blake_von_hauer_font_2_bold', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_font_2_italic', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_font_3', array( 'default' => 'Karla', 'sanitize_callback' => 'blake_von_hauer_sanitize_select' ) );
		$wp_customize->add_setting( 'blake_von_hauer_font_3_bold', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_font_3_italic', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_explanation_10', array( 'default' => '0', 'sanitize_callback' => 'blake_von_hauer_sanitize_null' ) );
		$wp_customize->add_setting( 'blake_von_hauer_swiFont_Menu', array( 'default' => 'blake-von-hauer-font-3', 'sanitize_callback' => 'blake_von_hauer_sanitize_font_switchers' ) );
		$wp_customize->add_setting( 'blake_von_hauer_swiFont_HLT', array( 'default' => 'blake-von-hauer-font-1', 'sanitize_callback' => 'blake_von_hauer_sanitize_font_switchers' ) );
		$wp_customize->add_setting( 'blake_von_hauer_swiFont_HAT', array( 'default' => 'blake-von-hauer-font-1', 'sanitize_callback' => 'blake_von_hauer_sanitize_font_switchers' ) );
		$wp_customize->add_setting( 'blake_von_hauer_swiFont_HAE', array( 'default' => 'blake-von-hauer-font-1', 'sanitize_callback' => 'blake_von_hauer_sanitize_font_switchers' ) );
		$wp_customize->add_setting( 'blake_von_hauer_swiFont_PostNav', array( 'default' => 'blake-von-hauer-font-1', 'sanitize_callback' => 'blake_von_hauer_sanitize_font_switchers' ) );
		$wp_customize->add_setting( 'blake_von_hauer_swiFont_RP', array( 'default' => 'blake-von-hauer-font-1', 'sanitize_callback' => 'blake_von_hauer_sanitize_font_switchers' ) );
		/* */

		/* Background & Colors */
		$wp_customize->add_setting( 'blake_von_hauer_color_Background', array( 'default' => '#eeeeee', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'blake_von_hauer_boxedBackground', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_upload_Background', array( 'sanitize_callback' => 'blake_von_hauer_sanitize_file' ) );
		$wp_customize->add_setting( 'blake_von_hauer_centerBackground', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_repeatBackground', array( 'default' => 'no-repeat', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_explanation_5', array( 'default' => '0', 'sanitize_callback' => 'blake_von_hauer_sanitize_null' ) );
		$wp_customize->add_setting( 'blake_von_hauer_color_White', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'blake_von_hauer_color_Pink', array( 'default' => '#ea667f', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'blake_von_hauer_color_Purple', array( 'default' => '#452a38', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'blake_von_hauer_color_Black', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'blake_von_hauer_color_Gray', array( 'default' => '#bdbdbd', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'blake_von_hauer_color_TextGray', array( 'default' => '#555', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'blake_von_hauer_color_TextLightGray', array( 'default' => '#999', 'sanitize_callback' => 'sanitize_hex_color' ) );
		/* */

		/* Header */
		$wp_customize->add_setting( 'blake_von_hauer_text_Logo', array( 'default' => wp_title(), 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_font_Logo', array( 'default' => 'Playfair_Display', 'sanitize_callback' => 'blake_von_hauer_sanitize_select' ) );
		$wp_customize->add_setting( 'blake_von_hauer_font_size_Logo', array( 'default' => 30, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_color_Logo', array( 'default' => '#452a38', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'blake_von_hauer_upload_Logo', array( 'sanitize_callback' => 'blake_von_hauer_sanitize_file' ) );
		$wp_customize->add_setting( 'blake_von_hauer_upload_MobileLogo', array( 'sanitize_callback' => 'blake_von_hauer_sanitize_file' ) );
		$wp_customize->add_setting( 'blake_von_hauer_upload_StickyLogo', array( 'sanitize_callback' => 'blake_von_hauer_sanitize_file' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_LogoPos', array( 'default' => 'logo-bottom', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_color_Logo_Background', array( 'default' => '#cccccc', 'sanitize_callback' => 'sanitize_hex_color' ) );
		$wp_customize->add_setting( 'blake_von_hauer_transparent_Logo_Background', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_maxLogoHeight', array( 'default' => 180, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_logoPaddingTop', array( 'default' => 40, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_logoPaddingRight', array( 'default' => 40, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_logoPaddingBottom', array( 'default' => 20, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_MenuPos', array( 'default' => 'menu-left', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_MenuWidth', array( 'default' => 'full_boxed', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_menuContainerHeight', array( 'default' => 66, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_menuPaddingLeft', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_menuPaddingRight', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_triggerSlicknav', array( 'default' => 960, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_slicknav_apl', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_triggerSticky', array( 'default' => 300, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_stickyHeader', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_TopLinePos', array( 'default' => 'right', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_TopLineWidth', array( 'default' => 'full_boxed', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_explanation_6', array( 'default' => '0', 'sanitize_callback' => 'blake_von_hauer_sanitize_null' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_StickyLogo', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_HeaderSocial', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_HeaderSearch', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_HeaderMenu', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		/* */

		/* Header, Upper & Home Widgets */
		$wp_customize->add_setting( 'blake_von_hauer_upperWidgetsCol', array( 'default' => '3col', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_UpperWidgets', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_UpperWidgetsFront', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_UpperWidgetsPage', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_UpperWidgetsPost', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_UpperWidgetsArchive', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_UpperWidgetsStatic', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_homeWidgetsCol', array( 'default' => '2col', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_HomeWidgets', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_HomeWidgetsFront', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		/* */

		/* Layout Options */
		$wp_customize->add_setting( 'blake_von_hauer_opt_PageWidth', array( 'default' => 'boxed', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_text_HomePosts', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_text_HidePosts', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_HomePosts', array( 'default' => 'all', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_Layout', array( 'default' => '1col_sidebar', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_explanation_2', array( 'default' => '0', 'sanitize_callback' => 'blake_von_hauer_sanitize_null' ) );
		$wp_customize->add_setting( 'blake_von_hauer_styleA_count', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_styleB_count', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_styleZ_count', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_Layout_Archive', array( 'default' => '1col_sidebar', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_explanation_11', array( 'default' => '0', 'sanitize_callback' => 'blake_von_hauer_sanitize_null' ) );
		$wp_customize->add_setting( 'blake_von_hauer_styleA_count_Archive', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_styleB_count_Archive', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_styleZ_count_Archive', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_explanation_4', array( 'default' => '0', 'sanitize_callback' => 'blake_von_hauer_sanitize_null' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_SidebarInnerPage', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_SidebarInnerStatic', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_ExtraSidebar_Archive', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_ExtraSidebar_Page', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_ExtraSidebar_Static', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_ExtraSidebar_Post', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		/* */

		/* Post Format: Standard */
		$wp_customize->add_setting( 'blake_von_hauer_explanation_7', array( 'default' => '0', 'sanitize_callback' => 'blake_von_hauer_sanitize_null' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_FeaImg_Single_Standard', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_SidebarPost_Standard', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		/* */

		/* Post Format: Video */
		$wp_customize->add_setting( 'blake_von_hauer_explanation_8', array( 'default' => '0', 'sanitize_callback' => 'blake_von_hauer_sanitize_null' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_SidebarPost_Video', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		/* */

		/* Post Format: Gallery */
		$wp_customize->add_setting( 'blake_von_hauer_explanation_9', array( 'default' => '0', 'sanitize_callback' => 'blake_von_hauer_sanitize_null' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_SidebarPost_Gallery', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_GalleryPos_Gallery', array( 'default' => 'content', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_bxControls', array( 'default' => 'arrow', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_bxAuto', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sliderPause', array( 'default' => 4000, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sliderMode', array( 'default' => 'horizontal', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sliderInfinite', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		/* */

		/* Related & Authorized Posts */
		$wp_customize->add_setting( 'blake_von_hauer_opt_RPBase', array( 'default' => 'tag', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_RelatedPosts', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_RPDate', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_APBase', array( 'default' => 'author', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_AuthorizedPosts', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_AuthorizedPosts_Gallery', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_AuthorizedPosts_Video', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_APType', array( 'default' => 'rand', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		/* */

		/* Footer */
		$wp_customize->add_setting( 'blake_von_hauer_opt_FooterWidgetsWidth', array( 'default' => 'boxed', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_footerWidgetsCol', array( 'default' => '3col', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_footerWidgets', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_FooterWidth', array( 'default' => 'boxed', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_bottomLine', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_FooterMenu', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_FooterSocial', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_text_Footer', array( 'default' => '2019 BLAKE von HAUER. ALL RIGHTS RESERVED.', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_InstagramShortcode', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_InstagramText', array( 'default' => 'FOLLOW @ INSTAGRAM', 'sanitize_callback' => 'sanitize_text_field' ) );
		/* */

		/* Show/Hide Elements */
		$wp_customize->add_setting( 'blake_von_hauer_sh_Date', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Date_Home', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_btnComments', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_btnComments_Home', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Hits', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Excerpt', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Excerpt_Home', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_TagBar', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_TagBar_Home', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_CategoryBar', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_CategoryBar_Home', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_btnReadMore', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Author', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_AuthorBox', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_FilterBar', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_FilterBar_Word', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_PostComments', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_PageComments', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_SocialBar', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_SocialBar_Page', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_SocialBar_Facebook', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_SocialBar_Twitter', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_SocialBar_Google', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		/* */

		/* Social Accounts */
		$wp_customize->add_setting( 'blake_von_hauer_sh_SocialAccounts', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Facebook', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Twitter', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Instagram', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Pinterest', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Google', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Tumblr', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Flickr', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Digg', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_LinkedIn', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Vimeo', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_YouTube', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Behance', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Dribble', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_DeviantArt', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Github', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Bloglovin', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_Lastfm', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_SoundCloud', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		$wp_customize->add_setting( 'blake_von_hauer_social_VK', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
		/* */

		/* Google Maps */
		$wp_customize->add_setting( 'blake_von_hauer_mapPage', array( 'sanitize_callback' => 'blake_von_hauer_returnMapPageID' ) );
		$wp_customize->add_setting( 'blake_von_hauer_coorN', array( 'default' => '49.0138', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_coorE', array( 'default' => '8.38624', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_rng_MapZoom', array( 'default' => 15, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_mapHeight', array( 'default' => 500, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Map', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_enableMapKey', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_mapAPI', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
		/* */

		/* Translation */
		$wp_customize->add_setting( 'blake_von_hauer_IgnorePOT', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Lang', array( 'default' => ( get_bloginfo( 'language' ) ), 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_ReadMore', array( 'default' => '/ READ MORE /', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_OlderPosts', array( 'default' => 'OLDER POSTS', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_NewerPosts', array( 'default' => 'NEWER POSTS', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_PrevPost', array( 'default' => 'PREVIOUS POST', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_NextPost', array( 'default' => 'NEXT POST', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_TypeKeyword', array( 'default' => 'TYPE KEYWORD TO SEARCH', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Views', array( 'default' => 'VIEWS', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_AllByAuthor', array( 'default' => 'VIEW ALL POSTS BY AUTHOR', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_AuthorWebsite', array( 'default' => 'VISIT AUTHOR WEBSITE', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_DontMiss', array( 'default' => 'DON\'T MISS THIS ONE:', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Page', array( 'default' => 'PAGE', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Sticky', array( 'default' => 'STICKY', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_ViewAll', array( 'default' => 'VIEW ALL', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_BackToTop', array( 'default' => 'BACK TO TOP', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_404', array( 'default' => 'PAGE NOT FOUND', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Nothing', array( 'default' => 'NOTHING FOUND', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_SearchResults', array( 'default' => 'SEARCH RESULTS', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Tag', array( 'default' => 'TAG', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Category', array( 'default' => 'CATEGORY', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Archives', array( 'default' => 'ARCHIVES', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Comment', array( 'default' => 'Comment', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Comments', array( 'default' => 'Comments', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Name', array( 'default' => 'NAME', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Email', array( 'default' => 'E-MAIL', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Website', array( 'default' => 'WEBSITE', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_MustBeLogged', array( 'default' => 'YOU MUST BE LOGGED IN TO POST A COMMENT', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_LoginToReply', array( 'default' => 'LOG IN TO REPLY', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Logged', array( 'default' => 'LOGGED IN', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_LogOut', array( 'default' => 'LOG OUT', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_LeaveReply', array( 'default' => 'Leave a Reply', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_CancelReply', array( 'default' => 'CANCEL REPLY', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_PostComment', array( 'default' => 'POST COMMENT', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_At', array( 'default' => 'AT', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Reply', array( 'default' => 'REPLY', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Edit', array( 'default' => 'EDIT', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Awaiting', array( 'default' => 'Comment awaiting approval.', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_tra_Cookie', array( 'default' => 'Save my name, email, and website in this browser for the next time I comment', 'sanitize_callback' => 'sanitize_text_field' ) );
		/* */

		/* Banner Management */
		$wp_customize->add_setting( 'blake_von_hauer_opt_ResponsiveBannerHide', array( 'default' => '640', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_text_Banner_1', array( 'default' => '', 'sanitize_callback' => 'blake_von_hauer_sanitize_let_html' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_BannerPos_1', array( 'default' => 'below-header', 'sanitize_callback' => 'blake_von_hauer_sanitize_banner_positions' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_ResponsiveBanner_1', array( 'default' => 'static', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Banner_1_Archive', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Banner_1_Post', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_text_Banner_2', array( 'default' => '', 'sanitize_callback' => 'blake_von_hauer_sanitize_let_html' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_BannerPos_2', array( 'default' => 'below-upper-widgets', 'sanitize_callback' => 'blake_von_hauer_sanitize_banner_positions' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_ResponsiveBanner_2', array( 'default' => 'static', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Banner_2_Archive', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Banner_2_Post', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_text_Banner_3', array( 'default' => '', 'sanitize_callback' => 'blake_von_hauer_sanitize_let_html' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_BannerPos_3', array( 'default' => 'after-first-post', 'sanitize_callback' => 'blake_von_hauer_sanitize_banner_positions' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_ResponsiveBanner_3', array( 'default' => 'static', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Banner_3_Archive', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Banner_3_Post', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_text_Banner_4', array( 'default' => '', 'sanitize_callback' => 'blake_von_hauer_sanitize_let_html' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_BannerPos_4', array( 'default' => 'below-blog-posts', 'sanitize_callback' => 'blake_von_hauer_sanitize_banner_positions' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_ResponsiveBanner_4', array( 'default' => 'static', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Banner_4_Archive', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Banner_4_Post', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_text_Banner_5', array( 'default' => '', 'sanitize_callback' => 'blake_von_hauer_sanitize_let_html' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_BannerPos_5', array( 'default' => 'below-post', 'sanitize_callback' => 'blake_von_hauer_sanitize_banner_positions' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_ResponsiveBanner_5', array( 'default' => 'static', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Banner_5_Archive', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Banner_5_Post', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_text_Banner_Header', array( 'default' => '', 'sanitize_callback' => 'blake_von_hauer_sanitize_let_html' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_Banner_Header', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		/* */

		/* Slider Settings */
		$wp_customize->add_setting( 'blake_von_hauer_explanation_12', array( 'default' => '0', 'sanitize_callback' => 'blake_von_hauer_sanitize_null' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sliderWidth', array( 'default' => 1160, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sliderHeight', array( 'default' => 600, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_SliderPosition', array( 'default' => 'cover', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sliderShortcode', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_explanation_8', array( 'default' => '0', 'sanitize_callback' => 'blake_von_hauer_sanitize_null' ) );
		$wp_customize->add_setting( 'blake_von_hauer_bpts', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sliderCategory', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
		$wp_customize->add_setting( 'blake_von_hauer_bptsNumber', array( 'default' => 5, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_bptsExclude', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_SliderHomeView', array( 'default' => 'home-all', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sliderHideMobile', array( 'default' => 'always', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_bxControls_Main', array( 'default' => 'both', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_opt_bxControls_Colors', array( 'default' => 'black', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sliderPause', array( 'default' => 4000, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		$wp_customize->add_setting( 'blake_von_hauer_bxAuto_Main', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sliderMode', array( 'default' => 'horizontal', 'sanitize_callback' => 'blake_von_hauer_sanitize_choices' ) );
		$wp_customize->add_setting( 'blake_von_hauer_explanation_9', array( 'default' => '0', 'sanitize_callback' => 'blake_von_hauer_sanitize_null' ) );
		$wp_customize->add_setting( 'blake_von_hauer_bptsDate', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_bptsAuthor', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_bptsComment', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_bptsCategories', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_bptsCaption', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_SliderArchive', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_SliderPost', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sh_SliderPage', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sliderInfinite', array( 'default' => 1, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_sliderRandom', array( 'default' => 0, 'sanitize_callback' => 'blake_von_hauer_sanitize_checkbox' ) );
		$wp_customize->add_setting( 'blake_von_hauer_rng_Sli_Box', array( 'default' => 90, 'sanitize_callback' => 'blake_von_hauer_sanitize_integer' ) );
		/* */

		/* Custom CSS */
		$wp_customize->add_setting( 'blake_von_hauer_text_CSS', array( 'default' => '', 'sanitize_callback' => 'blake_von_hauer_sanitize_let_html' ) );
		/* */

		////////////////////////////////////////////////////
		/*/////////////////// CONTROLS ///////////////////*/
		////////////////////////////////////////////////////

		/* Featured Image Settings */
		$wp_customize->add_control( 'blake_von_hauer_explanation_1', array(
			'label' => esc_html__( 'Important Note', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'When you upload an image into your media library, it gets the sizes below. If you change these settings AFTER you uploaded an image, the image will not change its sizes. So, you have to re-upload it or use a plugin like <a href="https://wordpress.org/plugins/regenerate-thumbnails/" target="_blank">Regenerate Thumbnails</a> which is a very good practice.', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionFeaturedImage',
			'settings' => 'blake_von_hauer_explanation_1',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_imageWidth', array(
			'label' => esc_html__( '1.1. Featured Image Width', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'Theme default: "1040"<br>Write "0" to not to resize the images.<br>Works for newly added images only.', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionFeaturedImage',
			'settings' => 'blake_von_hauer_imageWidth',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_imageHeight', array(
			'label' => esc_html__( '1.2. Featured Image Height', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'Theme default: "0"<br>Write "0" to not to crop the images.<br>Works for newly added images only.', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionFeaturedImage',
			'settings' => 'blake_von_hauer_imageHeight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_thumbnailImageWidth', array(
			'label' => esc_html__( '1.3. Thumbnail Image Width', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'Theme default: "640"<br>Works for newly added images only.<br>We strongly recommend to keep the ratio between thumbnail image height and thumbnail image width at "1,5".<br>Eg. 960/640 = 1,5', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionFeaturedImage',
			'settings' => 'blake_von_hauer_thumbnailImageWidth',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_thumbnailImageHeight', array(
			'label' => esc_html__( '1.4. Thumbnail Image Height', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'Theme default: "960<br>Works for newly added images only.<br>We strongly recommend to keep the ratio between thumbnail image height and thumbnail image width at "1,5".<br>Eg. 960/640 = 1,5', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionFeaturedImage',
			'settings' => 'blake_von_hauer_thumbnailImageHeight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_thumbnailImageWidth_Hor', array(
			'label' => esc_html__( '1.5. Thumbnail Width for Horizontal Images', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'Theme default: "360"<br>Only used if "Apply Horizontal Thumbnail Size" is checked in "BvH Post Options".<br>Works for newly added images only.<br>We strongly recommend to keep the ratio between thumbnail image height and thumbnail image width at "1,5".<br>Eg. 540/360 = 1,5', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionFeaturedImage',
			'settings' => 'blake_von_hauer_thumbnailImageWidth_Hor',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_thumbnailImageHeight_Hor', array(
			'label' => esc_html__( '1.6. Thumbnail Height for Horizontal Images', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'Theme default: "540<br>Only used if "Apply Horizontal Thumbnail Size" is checked in "BvH Post Options".<br>Works for newly added images only.<br>We strongly recommend to keep the ratio between thumbnail image height and thumbnail image width at "1,5".<br>Eg. 540/360 = 1,5', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionFeaturedImage',
			'settings' => 'blake_von_hauer_thumbnailImageHeight_Hor',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		/* */

		/* Font Settings */
		$wp_customize->add_control( new blake_von_hauer_font_selector( $wp_customize, 'blake_von_hauer_font_1', array(
			'label' => esc_html__( '2.1. Primary Font', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'description' => wp_kses( __( 'Main headers.<br>Theme default: "Playfair Display"', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'settings' => 'blake_von_hauer_font_1'
		) ) );
		$wp_customize->add_control( 'blake_von_hauer_font_1_bold', array(
			'label' => esc_html__( 'Use Bold Where Allowed', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'settings' => 'blake_von_hauer_font_1_bold',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_font_1_italic', array(
			'label' => esc_html__( 'Use Italic Where Allowed', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'settings' => 'blake_von_hauer_font_1_italic',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new blake_von_hauer_font_selector( $wp_customize, 'blake_von_hauer_font_2', array(
			'label' => esc_html__( '2.2. Secondary Font', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'description' => wp_kses( __( 'Content font.<br>Theme default: "PT Serif"', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'settings' => 'blake_von_hauer_font_2',
		) ) );
		$wp_customize->add_control( 'blake_von_hauer_font_2_bold', array(
			'label' => esc_html__( 'Use Bold Where Allowed', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'settings' => 'blake_von_hauer_font_2_bold',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_font_2_italic', array(
			'label' => esc_html__( 'Use Italic Where Allowed', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'settings' => 'blake_von_hauer_font_2_italic',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new blake_von_hauer_font_selector( $wp_customize, 'blake_von_hauer_font_3', array(
			'label' => esc_html__( '2.3. Tertiary Font', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'description' => wp_kses( __( 'Menu items, dates, form headers etc.<br>Theme default: "Karla"', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'settings' => 'blake_von_hauer_font_3',
		) ) );
		$wp_customize->add_control( 'blake_von_hauer_font_3_bold', array(
			'label' => esc_html__( 'Use Bold Where Allowed', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'settings' => 'blake_von_hauer_font_3_bold',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_font_3_italic', array(
			'label' => esc_html__( 'Use Italic Where Allowed', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'settings' => 'blake_von_hauer_font_3_italic',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_explanation_10', array(
			'label' => esc_html__( '2.4. Font Switching', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'settings' => 'blake_von_hauer_explanation_10',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( new blake_von_hauer_FontSwitcher( $wp_customize, 'blake_von_hauer_swiFont_Menu', array(
			'label' => esc_html__( 'Menu Items', 'blake-von-hauer' ),
			'description' => esc_html__( 'Theme default: "Tertiary Font"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'settings' => 'blake_von_hauer_swiFont_Menu'
		) ) );
		$wp_customize->add_control( new blake_von_hauer_FontSwitcher( $wp_customize, 'blake_von_hauer_swiFont_HLT', array(
			'label' => esc_html__( 'Blog Homepage Post Titles', 'blake-von-hauer' ),
			'description' => esc_html__( 'Theme default: "Primary Font"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'settings' => 'blake_von_hauer_swiFont_HLT'
		) ) );
		$wp_customize->add_control( new blake_von_hauer_FontSwitcher( $wp_customize, 'blake_von_hauer_swiFont_HAT', array(
			'label' => esc_html__( 'Post Page Titles', 'blake-von-hauer' ),
			'description' => esc_html__( 'Theme default: "Primary Font"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'settings' => 'blake_von_hauer_swiFont_HAT'
		) ) );
		$wp_customize->add_control( new blake_von_hauer_FontSwitcher( $wp_customize, 'blake_von_hauer_swiFont_HAE', array(
			'label' => esc_html__( 'Post Page Excerpt', 'blake-von-hauer' ),
			'description' => esc_html__( 'Theme default: "Primary Font"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'settings' => 'blake_von_hauer_swiFont_HAE'
		) ) );
		$wp_customize->add_control( new blake_von_hauer_FontSwitcher( $wp_customize, 'blake_von_hauer_swiFont_PostNav', array(
			'label' => esc_html__( 'Post Navigation', 'blake-von-hauer' ),
			'description' => esc_html__( 'Theme default: "Primary Font"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'settings' => 'blake_von_hauer_swiFont_PostNav'
		) ) );
		$wp_customize->add_control( new blake_von_hauer_FontSwitcher( $wp_customize, 'blake_von_hauer_swiFont_RP', array(
			'label' => esc_html__( 'Related Posts', 'blake-von-hauer' ),
			'description' => esc_html__( 'Theme default: "Primary Font"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFonts',
			'settings' => 'blake_von_hauer_swiFont_RP'
		) ) );
		/* */

		/* Background & Colors */
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blake_von_hauer_color_Background', array(
			'label' => esc_html__( '3.1. Background Color', 'blake-von-hauer' ),  'section' => 'blake_von_hauer_sectionBackground', 'settings' => 'blake_von_hauer_color_Background'
		) ) );
		$wp_customize->add_control( 'blake_von_hauer_boxedBackground', array(
			'label' => esc_html__( 'Boxed Background', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBackground',
			'settings' => 'blake_von_hauer_boxedBackground',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control(
			new WP_Customize_Image_Control( $wp_customize, 'blake_von_hauer_upload_Background', array(
					'label' => esc_html__( '3.2. Background Image', 'blake-von-hauer' ),

					'section' => 'blake_von_hauer_sectionBackground',
					'settings' => 'blake_von_hauer_upload_Background'
				)
			)
		);
		$wp_customize->add_control( 'blake_von_hauer_centerBackground', array(
			'label' => esc_html__( 'Centered Background Image', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBackground',
			'settings' => 'blake_von_hauer_centerBackground',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_repeatBackground', array(
			'label' => esc_html__( '3.3. Background Repeat Options', 'blake-von-hauer' ),
			'description' => esc_html__( 'Only used if "Centered" is unchecked.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBackground',
			'settings' => 'blake_von_hauer_repeatBackground',
			'type' => 'radio',
			'choices' => array(
				'no-repeat' => 'No Repeat',
				'repeat-x' => 'Repeat Only Horizontally',
				'repeat-y' => 'Repeat Only Vertically',
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_explanation_5', array(
			'label' => esc_html__( '3.4. Colors', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionBackground',
			'settings' => 'blake_von_hauer_explanation_5',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blake_von_hauer_color_Pink', array(
			'label' => esc_html__( 'Primary Color', 'blake-von-hauer' ),  'section' => 'blake_von_hauer_sectionBackground', 'settings' => 'blake_von_hauer_color_Pink'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blake_von_hauer_color_Purple', array(
			'label' => esc_html__( 'Secondary Color', 'blake-von-hauer' ),  'section' => 'blake_von_hauer_sectionBackground', 'settings' => 'blake_von_hauer_color_Purple'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blake_von_hauer_color_White', array(
			'label' => esc_html__( 'Combine with Primary + Secondary Color', 'blake-von-hauer' ),  'section' => 'blake_von_hauer_sectionBackground', 'settings' => 'blake_von_hauer_color_White'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blake_von_hauer_color_Gray', array(
			'label' => esc_html__( 'Tertiary Color', 'blake-von-hauer' ),  'section' => 'blake_von_hauer_sectionBackground', 'settings' => 'blake_von_hauer_color_Gray'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blake_von_hauer_color_Black', array(
			'label' => esc_html__( 'Heading Color', 'blake-von-hauer' ),  'section' => 'blake_von_hauer_sectionBackground', 'settings' => 'blake_von_hauer_color_Black'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blake_von_hauer_color_TextGray', array(
			'label' => esc_html__( 'Text Color', 'blake-von-hauer' ),  'section' => 'blake_von_hauer_sectionBackground', 'settings' => 'blake_von_hauer_color_TextGray'
		) ) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blake_von_hauer_color_TextLightGray', array(
			'label' => esc_html__( 'Light Text Color', 'blake-von-hauer' ),  'section' => 'blake_von_hauer_sectionBackground', 'settings' => 'blake_von_hauer_color_TextLightGray'
		) ) );
		/* */

		/* Header */
		if ( !function_exists( 'wp_site_icon' ) ) {
			$wp_customize->add_control(
				new WP_Customize_Image_Control( $wp_customize, 'blake_von_hauer_upload_Favicon', array(
						'label' => esc_html__( 'Upload a Favicon', 'blake-von-hauer' ),

						'section' => 'blake_von_hauer_sectionFeaturedImage',
						'settings' => 'blake_von_hauer_upload_Favicon'
					)
				)
			);
		}
		$wp_customize->add_control( 'blake_von_hauer_text_Logo', array(
			'label' => esc_html__( '4.1. Logo Text', 'blake-von-hauer' ),
			'description' => esc_html__( 'Leave blank if you want to use the "Site Title". If a logo image is uploaded, this will never be shown.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_text_Logo',
			'type' => 'text',
		) );
		$wp_customize->add_control( new blake_von_hauer_font_selector( $wp_customize, 'blake_von_hauer_font_Logo', array(
			'label' => esc_html__( '4.2. Logo Font', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'description' => esc_html__( 'Theme default: "Playfair Display"', 'blake-von-hauer' ),
			'settings' => 'blake_von_hauer_font_Logo'
		) ) );
		$wp_customize->add_control( 'blake_von_hauer_font_size_Logo', array(
			'label' => esc_html__( '4.3. Logo Font Size', 'blake-von-hauer' ),
			'description' => esc_html__( 'Theme default: "30"(px)', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_font_size_Logo',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 50px;',
			),
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blake_von_hauer_color_Logo', array(
			'label' => esc_html__( '4.4. Logo Text Color', 'blake-von-hauer' ),  'section' => 'blake_von_hauer_sectionHeader', 'settings' => 'blake_von_hauer_color_Logo'
		) ) );
		$wp_customize->add_control(
			new WP_Customize_Image_Control( $wp_customize, 'blake_von_hauer_upload_Logo', array(
					'label' => esc_html__( '4.5. Logo Image', 'blake-von-hauer' ),
					'section' => 'blake_von_hauer_sectionHeader',
					'settings' => 'blake_von_hauer_upload_Logo'
				)
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control( $wp_customize, 'blake_von_hauer_upload_MobileLogo', array(
					'label' => esc_html__( 'Mobile Logo Image', 'blake-von-hauer' ),
					'section' => 'blake_von_hauer_sectionHeader',
					'settings' => 'blake_von_hauer_upload_MobileLogo'
				)
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control( $wp_customize, 'blake_von_hauer_upload_StickyLogo', array(
					'label' => esc_html__( '4.6. Sticky Logo Image', 'blake-von-hauer' ),
					'section' => 'blake_von_hauer_sectionHeader',
					'settings' => 'blake_von_hauer_upload_StickyLogo'
				)
			)
		);
		$wp_customize->add_control( 'blake_von_hauer_opt_LogoPos', array(
			'label' => esc_html__( '4.7. Logo Position', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_opt_LogoPos',
			'type' => 'radio',
			'choices' => array(
				'logo-top' => 'Top',
				'logo-left' => 'Left',
				'logo-bottom' => 'Bottom'
			)
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'blake_von_hauer_color_Logo_Background', array(
			'label' => esc_html__( '4.8. Logo Background Color', 'blake-von-hauer' ), 'description' => esc_html__( 'Only used if "Logo Position" is NOT "Left".', 'blake-von-hauer' ), 'section' => 'blake_von_hauer_sectionHeader', 'settings' => 'blake_von_hauer_color_Logo_Background'
		) ) );
		$wp_customize->add_control( 'blake_von_hauer_transparent_Logo_Background', array(
			'label' => esc_html__( 'Transparent Logo Background', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_transparent_Logo_Background',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_maxLogoHeight', array(
			'label' => esc_html__( '4.9. Logo Height', 'blake-von-hauer' ),
			'description' => esc_html__( 'Will be ignored if higher than "Menu Container Height" when "Logo Position" is "Left". Only used if a logo image is uploaded.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_maxLogoHeight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 50px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_logoPaddingTop', array(
			'label' => esc_html__( '4.10. Logo Top Padding', 'blake-von-hauer' ),
			'description' => esc_html__( 'Only used if "Logo Position" is NOT "Left".', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_logoPaddingTop',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_logoPaddingRight', array(
			'label' => esc_html__( '4.11. Logo Right Padding', 'blake-von-hauer' ),
			'description' => esc_html__( 'Space between the logo and the menu. Only used if "Logo Position" is "Left".', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_logoPaddingRight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_logoPaddingBottom', array(
			'label' => esc_html__( '4.12. Logo Bottom Padding', 'blake-von-hauer' ),
			'description' => esc_html__( 'Only used if "Logo Position" is NOT "Left".', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_logoPaddingBottom',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_MenuPos', array(
			'label' => esc_html__( '4.13. Menu Position', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_opt_MenuPos',
			'type' => 'radio',
			'choices' => array(
				'menu-left' => 'Left',
				'menu-center' => 'Center',
				'menu-right' => 'Right'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_MenuWidth', array(
			'label' => esc_html__( '4.14. Menu Container Width', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',

			'settings' => 'blake_von_hauer_opt_MenuWidth',
			'type' => 'radio',
			'choices' => array(
				'boxed' => 'Boxed',
				'full' => 'Fullwidth',
				'full_boxed' => 'Fullwidth Background + Boxed'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_menuContainerHeight', array(
			'label' => esc_html__( '4.15. Menu Container Height', 'blake-von-hauer' ),
			'description' => esc_html__( 'min 35.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_menuContainerHeight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_menuPaddingLeft', array(
			'label' => esc_html__( '4.16. Menu Container Left Padding', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_menuPaddingLeft',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_menuPaddingRight', array(
			'label' => esc_html__( '4.17. Menu Container Right Padding', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_menuPaddingRight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_triggerSlicknav', array(
			'label' => esc_html__( '4.18. Trigger Mobile Menu', 'blake-von-hauer' ),
			'description' => esc_html__( 'Trigger mobile menu when window width is smaller than:', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_triggerSlicknav',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 80px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_slicknav_apl', array(
			'label' => esc_html__( 'Clickable Parent Menu Items in Mobile Menu', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_slicknav_apl',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_triggerSticky', array(
			'label' => esc_html__( '4.19. Sticky Header', 'blake-von-hauer' ),
			'description' => esc_html__( 'Trigger sticky header when scroll position is higher than:', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_triggerSticky',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 80px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_stickyHeader', array(
			'label' => esc_html__( 'Sticky Header', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_stickyHeader',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_TopLinePos', array(
			'label' => esc_html__( '4.20. Header Menu Position', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_opt_TopLinePos',
			'type' => 'radio',
			'choices' => array(
				'left' => 'Left',
				'center' => 'Center',
				'right' => 'Right'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_TopLineWidth', array(
			'label' => esc_html__( '4.21. Header Menu Container Width', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',

			'settings' => 'blake_von_hauer_opt_TopLineWidth',
			'type' => 'radio',
			'choices' => array(
				'boxed' => 'Boxed',
				'full' => 'Fullwidth',
				'full_boxed' => 'Fullwidth Background + Boxed'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_explanation_6', array(
			'label' => esc_html__( '4.22. Show/Hide', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_explanation_6',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_StickyLogo', array(
			'label' => esc_html__( 'Show Sticky Logo', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_sh_StickyLogo',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_HeaderSocial', array(
			'label' => esc_html__( 'Show Social Account Icons', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_sh_HeaderSocial',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_HeaderSearch', array(
			'label' => esc_html__( 'Show Search', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_sh_HeaderSearch',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_HeaderMenu', array(
			'label' => esc_html__( 'Show Header Menu', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHeader',
			'settings' => 'blake_von_hauer_sh_HeaderMenu',
			'type' => 'checkbox'
		) );
		/* */

		/* Header, Upper & Home Widgets */
		$wp_customize->add_control( 'blake_von_hauer_upperWidgetsCol', array(
			'label' => esc_html__( '5.1. Upper Widget Columns', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHomeWidgets',
			'settings' => 'blake_von_hauer_upperWidgetsCol',
			'type' => 'radio',
			'choices' => array(
				'2col' => '2 Columns',
				'3col' => '3 Columns'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_UpperWidgets', array(
			'label' => esc_html__( 'Show Upper Widgets on Blog Homepage', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHomeWidgets',
			'settings' => 'blake_von_hauer_sh_UpperWidgets',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_UpperWidgetsFront', array(
			'label' => esc_html__( 'First Page Upper Widgets', 'blake-von-hauer' ),
			'description' => esc_html__( 'Shows upper widgets only on the first page of pagination. Only used if "Show Upper Widgets on Blog Homepage" is checked.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHomeWidgets',
			'settings' => 'blake_von_hauer_sh_UpperWidgetsFront',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_UpperWidgetsPage', array(
			'label' => esc_html__( 'Show Upper Widgets on Pages', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHomeWidgets',
			'settings' => 'blake_von_hauer_sh_UpperWidgetsPage',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_UpperWidgetsPost', array(
			'label' => esc_html__( 'Show Upper Widgets on Posts', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHomeWidgets',
			'settings' => 'blake_von_hauer_sh_UpperWidgetsPost',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_UpperWidgetsArchive', array(
			'label' => esc_html__( 'Show Upper Widgets on Archives', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHomeWidgets',
			'settings' => 'blake_von_hauer_sh_UpperWidgetsArchive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_UpperWidgetsStatic', array(
			'label' => esc_html__( 'Show Upper Widgets on Static Front Page', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHomeWidgets',
			'settings' => 'blake_von_hauer_sh_UpperWidgetsStatic',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_homeWidgetsCol', array(
			'label' => esc_html__( '5.2. Blog Homepage Widget Columns', 'blake-von-hauer' ),
			'description' => esc_html__( '3 columns option is only used with layouts have no sidebar.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHomeWidgets',
			'settings' => 'blake_von_hauer_homeWidgetsCol',
			'type' => 'radio',
			'choices' => array(
				'2col' => '2 Columns',
				'3col' => '3 Columns'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_HomeWidgets', array(
			'label' => esc_html__( 'Show Blog Homepage Widgets', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHomeWidgets',
			'settings' => 'blake_von_hauer_sh_HomeWidgets',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_HomeWidgetsFront', array(
			'label' => esc_html__( 'First Page Home Widgets', 'blake-von-hauer' ),
			'description' => esc_html__( 'Shows blog homepage widgets only on the first page of pagination. Only used if "Show Blog Homepage Widgets" is checked.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionHomeWidgets',
			'settings' => 'blake_von_hauer_sh_HomeWidgetsFront',
			'type' => 'checkbox'
		) );
		/* */

		/* Layout Options */
		$wp_customize->add_control( 'blake_von_hauer_opt_PageWidth', array(
			'label' => esc_html__( '6.1. Container Width', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionLayout',

			'settings' => 'blake_von_hauer_opt_PageWidth',
			'type' => 'radio',
			'choices' => array(
				'boxed' => 'Boxed',
				'full' => 'Fullwidth'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_text_HomePosts', array(
			'label' => esc_html__( '6.2. Show/Hide Specific Categories on Blog Homepage', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'Write category IDs you want to show or hide. Use comma (,) between them.<br>Example: 2,5,8', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_text_HomePosts',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_HomePosts', array(
			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_opt_HomePosts',
			'type' => 'radio',
			'choices' => array(
				'all' => 'Show All Categories',
				'hidecats' => 'Hide Chosen Categories',
				'showcats' => 'Show Chosen Categories'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_text_HidePosts', array(
			'label' => esc_html__( '6.3. Hide Specific Posts on Blog Homepage', 'blake-von-hauer' ),
			'description' => esc_html__( 'Write post IDs you want to hide.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_text_HidePosts',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_Layout', array(
			'label' => esc_html__( '6.4. Blog Homepage Display Options', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_opt_Layout',
			'type' => 'radio',
			'choices' => array(
				'1col' => '1 Column',
				'1col_sidebar' => '1 Column + Sidebar',
				'2col' => '2 Columns',
				'2col_sidebar' => '2 Columns + Sidebar',
				'1_2col' => '(1 + 2) Columns',
				'1_2col_sidebar' => '(1 + 2) Columns + Sidebar',
				'3col' => '3 Columns',
				'1_3col' => '(1 + 3) Columns',
				'2_3col' => '(2 + 3) Columns'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_explanation_2', array(
			'label' => esc_html__( '6.5. Blog Homepage Listing Style Options', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'If the sum of Style A, B and Z is bigger than the number of posts per page, your settings will be ignored and all the posts will be shown in Style A.<br><br>If the sum of Style A, B and Z is smaller than the number of posts per page, Style A will take effect to complete the count.', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_explanation_2',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_styleA_count', array(
			'section' => 'blake_von_hauer_sectionLayout',
			'description' => esc_html__( 'Number of posts to show in "Style A":', 'blake-von-hauer' ),
			'settings' => 'blake_von_hauer_styleA_count',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_styleB_count', array(
			'section' => 'blake_von_hauer_sectionLayout',
			'description' => esc_html__( 'Number of posts to show in "Style B":', 'blake-von-hauer' ),
			'settings' => 'blake_von_hauer_styleB_count',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_styleZ_count', array(
			'section' => 'blake_von_hauer_sectionLayout',
			'description' => esc_html__( 'Number of posts to show in "Style Z":', 'blake-von-hauer' ),
			'settings' => 'blake_von_hauer_styleZ_count',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_Layout_Archive', array(
			'label' => esc_html__( '6.6. Archive Display Options', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_opt_Layout_Archive',
			'type' => 'radio',
			'choices' => array(
				'1col' => '1 Column',
				'1col_sidebar' => '1 Column + Sidebar',
				'2col' => '2 Columns',
				'2col_sidebar' => '2 Columns + Sidebar',
				'1_2col' => '(1 + 2) Columns',
				'1_2col_sidebar' => '(1 + 2) Columns + Sidebar',
				'3col' => '3 Columns',
				'1_3col' => '(1 + 3) Columns',
				'2_3col' => '(2 + 3) Columns'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_explanation_11', array(
			'label' => esc_html__( '6.7. Archive Listing Style Options', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_explanation_11',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_styleA_count_Archive', array(
			'section' => 'blake_von_hauer_sectionLayout',
			'description' => esc_html__( 'Number of posts to show in "Style A":', 'blake-von-hauer' ),
			'settings' => 'blake_von_hauer_styleA_count_Archive',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_styleB_count_Archive', array(
			'section' => 'blake_von_hauer_sectionLayout',
			'description' => esc_html__( 'Number of posts to show in "Style B":', 'blake-von-hauer' ),
			'settings' => 'blake_von_hauer_styleB_count_Archive',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_styleZ_count_Archive', array(
			'section' => 'blake_von_hauer_sectionLayout',
			'description' => esc_html__( 'Number of posts to show in "Style Z":', 'blake-von-hauer' ),
			'settings' => 'blake_von_hauer_styleZ_count_Archive',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_explanation_4', array(
			'label' => esc_html__( '6.8. Sidebar Options', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_explanation_4',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_SidebarInnerPage', array(
			'label' => esc_html__( 'Show Sidebar on Pages', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_sh_SidebarInnerPage',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_SidebarInnerStatic', array(
			'label' => esc_html__( 'Show Sidebar on Static Front Page', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_sh_SidebarInnerStatic',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_ExtraSidebar_Archive', array(
			'label' => esc_html__( 'Enable "Sidebar - Archive"', 'blake-von-hauer' ),
			'description' => esc_html__( 'Uncheck to use the default sidebar.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_ExtraSidebar_Archive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_ExtraSidebar_Page', array(
			'label' => esc_html__( 'Enable "Sidebar - Page"', 'blake-von-hauer' ),
			'description' => esc_html__( 'Uncheck to use the default sidebar.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_ExtraSidebar_Page',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_ExtraSidebar_Static', array(
			'label' => esc_html__( 'Enable "Sidebar - Static Front Page"', 'blake-von-hauer' ),
			'description' => esc_html__( 'Uncheck to use the default sidebar.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_ExtraSidebar_Static',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_ExtraSidebar_Post', array(
			'label' => esc_html__( 'Enable "Sidebar - Post"', 'blake-von-hauer' ),
			'description' => esc_html__( 'Uncheck to use the default sidebar.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionLayout',
			'settings' => 'blake_von_hauer_ExtraSidebar_Post',
			'type' => 'checkbox'
		) );
		/* */

		/* Post Format: Standard */
		$wp_customize->add_control( 'blake_von_hauer_explanation_7', array(
			'label' => esc_html__( '7.1. Standard Posts', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionPostFormats',
			'settings' => 'blake_von_hauer_explanation_7',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_FeaImg_Single_Standard', array(
			'label' => esc_html__( 'Show Featured Image on Post Pages', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionPostFormats',
			'settings' => 'blake_von_hauer_sh_FeaImg_Single_Standard',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_SidebarPost_Standard', array(
			'label' => esc_html__( 'Show Sidebar on Standard Posts', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionPostFormats',
			'settings' => 'blake_von_hauer_sh_SidebarPost_Standard',
			'type' => 'checkbox',
		) );
		/* */

		/* Post Format: Video */
		$wp_customize->add_control( 'blake_von_hauer_explanation_8', array(
			'label' => esc_html__( '7.2. Video Posts', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionPostFormats',
			'settings' => 'blake_von_hauer_explanation_8',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_SidebarPost_Video', array(
			'label' => esc_html__( 'Show Sidebar on Video Posts', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionPostFormats',
			'settings' => 'blake_von_hauer_sh_SidebarPost_Video',
			'type' => 'checkbox',
		) );
		/* */

		/* Post Format: Gallery */
		$wp_customize->add_control( 'blake_von_hauer_explanation_9', array(
			'label' => esc_html__( '7.3. Gallery Posts', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionPostFormats',
			'settings' => 'blake_von_hauer_explanation_9',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_SidebarPost_Gallery', array(
			'label' => esc_html__( 'Show Sidebar on Gallery Posts', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionPostFormats',
			'settings' => 'blake_von_hauer_sh_SidebarPost_Gallery',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_GalleryPos_Gallery', array(
			'label' => esc_html__( 'Gallery Position', 'blake-von-hauer' ),
			'description' => esc_html__( 'Choose the gallery position on post page.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionPostFormats',
			'settings' => 'blake_von_hauer_opt_GalleryPos_Gallery',
			'type' => 'radio',
			'choices' => array(
				'content' => 'Only in Content',
				'iof' => 'Instead of Featured Image',
				'both' => 'Both'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_bxControls', array(
			'label' => esc_html__( 'Gallery Slider Settings', 'blake-von-hauer' ),
			'description' => esc_html__( 'Video sliders will use these settings too but they can not have pager bullets.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionPostFormats',
			'settings' => 'blake_von_hauer_opt_bxControls',
			'type' => 'radio',
			'choices' => array(
				'arrow' => 'Show Prev/Next Arrows',
				'bullet' => 'Show Pager Bullets',
				'both' => 'Show Both',
				'none' => 'None'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_bxAuto', array(
			'label' => esc_html__( 'Autoplay Slides', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionPostFormats',
			'settings' => 'blake_von_hauer_bxAuto',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sliderPause', array(
			'label' => esc_html__( 'Autoplay Duration', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'Theme default: "4000"<br>Only used if "Autoplay Slides" is checked.', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionPostFormats',
			'settings' => 'blake_von_hauer_sliderPause',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_sliderMode', array(
			'label' => esc_html__( 'Transition Effect', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionPostFormats',
			'settings' => 'blake_von_hauer_sliderMode',
			'type' => 'radio',
			'choices' => array(
				'horizontal' => 'Horizontal',
				'fade' => 'Fade'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sliderInfinite', array(
			'label' => esc_html__( 'Infinite Loop', 'blake-von-hauer' ),
			'description' => esc_html__( 'If checked, clicking "Next" while on the last slide will transition to the first slide and vice-versa.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionPostFormats',
			'settings' => 'blake_von_hauer_sliderInfinite',
			'type' => 'checkbox',
		) );
		/* */

		/* Related & Authorized Posts */
		$wp_customize->add_control( 'blake_von_hauer_opt_RPBase', array(
			'label' => esc_html__( '8.1. Related Posts', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionRP',

			'settings' => 'blake_von_hauer_opt_RPBase',
			'type' => 'radio',
			'choices' => array(
				'author' => 'Author Based',
				'tag' => 'Tag Based',
				'category' => 'Category Based'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_RelatedPosts', array(
			'label' => esc_html__( 'Show Related Posts', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionRP',
			'settings' => 'blake_von_hauer_sh_RelatedPosts',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_RPDate', array(
			'label' => esc_html__( 'Show Date', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionRP',
			'settings' => 'blake_von_hauer_sh_RPDate',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_APBase', array(
			'label' => esc_html__( '8.2. Call-to-Action Lines', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionRP',

			'settings' => 'blake_von_hauer_opt_APBase',
			'type' => 'radio',
			'choices' => array(
				'author' => 'Author Based',
				'tag' => 'Tag Based',
				'category' => 'Category Based'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_AuthorizedPosts', array(
			'label' => esc_html__( 'Show on Standard Post Pages', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionRP',
			'settings' => 'blake_von_hauer_sh_AuthorizedPosts',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_AuthorizedPosts_Gallery', array(
			'label' => esc_html__( 'Show on Gallery Post Pages', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionRP',
			'settings' => 'blake_von_hauer_sh_AuthorizedPosts_Gallery',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_AuthorizedPosts_Video', array(
			'label' => esc_html__( 'Show on Video Post Pages', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionRP',
			'settings' => 'blake_von_hauer_sh_AuthorizedPosts_Video',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_APType', array(
			'section' => 'blake_von_hauer_sectionRP',

			'settings' => 'blake_von_hauer_opt_APType',
			'type' => 'radio',
			'choices' => array(
				'rand' => 'Show a Random Post',
				'date' => 'Show the Latest Post'
			)
		) );
		/* */

		/* Footer */
		$wp_customize->add_control( 'blake_von_hauer_opt_FooterWidgetsWidth', array(
			'label' => esc_html__( '9.1. Widget Container Width', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFooter',

			'settings' => 'blake_von_hauer_opt_FooterWidgetsWidth',
			'type' => 'radio',
			'choices' => array(
				'boxed' => 'Boxed',
				'full' => 'Fullwidth'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_footerWidgetsCol', array(
			'label' => esc_html__( '9.2. Widget Columns', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFooter',

			'settings' => 'blake_von_hauer_footerWidgetsCol',
			'type' => 'radio',
			'choices' => array(
				'2col' => '2 Columns',
				'3col' => '3 Columns'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_footerWidgets', array(
			'label' => esc_html__( 'Show Widgets', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFooter',
			'settings' => 'blake_von_hauer_sh_footerWidgets',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_FooterWidth', array(
			'label' => esc_html__( '9.3. Bottom Bar Container Width', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFooter',

			'settings' => 'blake_von_hauer_opt_FooterWidth',
			'type' => 'radio',
			'choices' => array(
				'boxed' => 'Boxed',
				'full' => 'Fullwidth'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_bottomLine', array(
			'label' => esc_html__( 'Show Bottom Bar', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFooter',
			'settings' => 'blake_von_hauer_sh_bottomLine',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_FooterMenu', array(
			'label' => esc_html__( 'Show Footer Menu', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFooter',
			'settings' => 'blake_von_hauer_sh_FooterMenu',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_FooterSocial', array(
			'label' => esc_html__( 'Show Social Account Icons', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFooter',
			'settings' => 'blake_von_hauer_sh_FooterSocial',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_text_Footer', array(
			'label' => esc_html__( '9.4. Copyright Text', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFooter',
			'settings' => 'blake_von_hauer_text_Footer',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_InstagramShortcode', array(
			'label' => esc_html__( '9.5. Instagram Slider Widget', 'blake-von-hauer' ),
			'description' => esc_html__( 'Shortcode:', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFooter',
			'settings' => 'blake_von_hauer_InstagramShortcode',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_InstagramText', array(
			'description' => esc_html__( 'Text:', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionFooter',
			'settings' => 'blake_von_hauer_InstagramText',
			'type' => 'text',
		) );
		/* */

		/* Show/Hide Elements */
		$wp_customize->add_control( 'blake_von_hauer_sh_Date', array(
			'label' => esc_html__( 'Show Date', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_Date',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Date_Home', array(
			'label' => esc_html__( 'Show Date', 'blake-von-hauer' ),
			'description' => esc_html__( 'For indexed views like home, archives etc.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_Date_Home',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_btnComments', array(
			'label' => esc_html__( 'Show Comments Icon', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_btnComments',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_btnComments_Home', array(
			'label' => esc_html__( 'Show Comments Icon', 'blake-von-hauer' ),
			'description' => esc_html__( 'For indexed views like home, archives etc.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_btnComments_Home',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Hits', array(
			'label' => esc_html__( 'Show Hit Counter', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_Hits',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Excerpt', array(
			'label' => esc_html__( 'Show Excerpt', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_Excerpt',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Excerpt_Home', array(
			'label' => esc_html__( 'Show Excerpt', 'blake-von-hauer' ),
			'description' => esc_html__( 'For indexed views like home, archives etc.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_Excerpt_Home',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_TagBar', array(
			'label' => esc_html__( 'Show Tags', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_TagBar',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_TagBar_Home', array(
			'label' => esc_html__( 'Show Tags', 'blake-von-hauer' ),
			'description' => esc_html__( 'For indexed views like home, archives etc.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_TagBar_Home',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_CategoryBar', array(
			'label' => esc_html__( 'Show Categories', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_CategoryBar',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_CategoryBar_Home', array(
			'label' => esc_html__( 'Show Categories', 'blake-von-hauer' ),
			'description' => esc_html__( 'For indexed views like home, archives etc.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_CategoryBar_Home',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_btnReadMore', array(
			'label' => esc_html__( 'Show Read More Button', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_btnReadMore',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Author', array(
			'label' => esc_html__( 'Show Author', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_Author',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_AuthorBox', array(
			'label' => esc_html__( 'Show Author Box on Post Pages', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_AuthorBox',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_FilterBar', array(
			'label' => esc_html__( 'Show Filter Bar on Archive Pages', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_FilterBar',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_FilterBar_Word', array(
			'label' => esc_html__( 'Show "Tag /", "Category /", "Search Results /" etc. on Filter Bar', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_FilterBar_Word',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_PostComments', array(
			'label' => esc_html__( 'Show Post Comments', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_PostComments',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_PageComments', array(
			'label' => esc_html__( 'Show Page Comments', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_PageComments',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_SocialBar', array(
			'label' => esc_html__( 'Show Share Icons', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_SocialBar',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_SocialBar_Page', array(
			'label' => esc_html__( 'Show Share Icons on Pages', 'blake-von-hauer' ),
			'description' => esc_html__( 'Only used if "Show Share Icons" is checked.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_SocialBar_Page',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_SocialBar_Facebook', array(
			'label' => esc_html__( 'Show Facebook Share Icon', 'blake-von-hauer' ),
			'description' => esc_html__( 'Only used if "Show Share Icons" is checked.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_SocialBar_Facebook',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_SocialBar_Twitter', array(
			'label' => esc_html__( 'Show Twitter Share Icon', 'blake-von-hauer' ),
			'description' => esc_html__( 'Only used if "Show Share Icons" is checked.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_SocialBar_Twitter',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_SocialBar_Google', array(
			'label' => esc_html__( 'Show Google Share Icon', 'blake-von-hauer' ),
			'description' => esc_html__( 'Only used if "Show Share Icons" is checked.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionShowHide',
			'settings' => 'blake_von_hauer_sh_SocialBar_Google',
			'type' => 'checkbox',
		) );
		/* */

		/* Social Accounts */
		$wp_customize->add_control( 'blake_von_hauer_sh_SocialAccounts', array(
			'label' => esc_html__( 'Show Social Account Icons', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_sh_SocialAccounts',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Facebook', array(
			'label' => esc_html__( 'Facebook', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Facebook',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Twitter', array(
			'label' => esc_html__( 'Twitter', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Twitter',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Instagram', array(
			'label' => esc_html__( 'Instagram', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Instagram',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Pinterest', array(
			'label' => esc_html__( 'Pinterest', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Pinterest',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Google', array(
			'label' => esc_html__( 'Google+', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Google',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Tumblr', array(
			'label' => esc_html__( 'Tumblr', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Tumblr',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Flickr', array(
			'label' => esc_html__( 'Flickr', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Flickr',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Digg', array(
			'label' => esc_html__( 'Digg', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Digg',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_LinkedIn', array(
			'label' => esc_html__( 'LinkedIn', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_LinkedIn',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Vimeo', array(
			'label' => esc_html__( 'Vimeo', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Vimeo',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_YouTube', array(
			'label' => esc_html__( 'YouTube', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_YouTube',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Behance', array(
			'label' => esc_html__( 'Behance', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Behance',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Dribble', array(
			'label' => esc_html__( 'Dribbble', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Dribble',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_DeviantArt', array(
			'label' => esc_html__( 'DeviantArt', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_DeviantArt',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Github', array(
			'label' => esc_html__( 'Github', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Github',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Bloglovin', array(
			'label' => esc_html__( 'Bloglovin', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Bloglovin',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_Lastfm', array(
			'label' => esc_html__( 'Last.fm', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_Lastfm',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_SoundCloud', array(
			'label' => esc_html__( 'SoundCloud', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_SoundCloud',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_social_VK', array(
			'label' => esc_html__( 'VK', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSocial',
			'settings' => 'blake_von_hauer_social_VK',
			'type' => 'text',
		) );
		/* */

		/* Google Maps */
		$wp_customize->add_control( 'blake_von_hauer_mapPage', array(
			'label' => esc_html__( 'Choose a Page', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionGoogleMaps',
			'settings' => 'blake_von_hauer_mapPage',
			 'type' => 'dropdown-pages',
		) );
		$wp_customize->add_control( 'blake_von_hauer_coorN', array(
			'label' => esc_html__( 'Coordinate N', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionGoogleMaps',
			'settings' => 'blake_von_hauer_coorN',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_coorE', array(
			'label' => esc_html__( 'Coordinate E', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionGoogleMaps',
			'settings' => 'blake_von_hauer_coorE',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_rng_MapZoom', array(
			'type'        => 'range',
			'section'     => 'blake_von_hauer_sectionGoogleMaps',
			'label'       => 'Zoom Level',

			'input_attrs' => array(
				'min'   => 5,
				'max'   => 19,
				'step'  => 1
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_mapHeight', array(
			'label' => esc_html__( 'Map Height', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionGoogleMaps',
			'settings' => 'blake_von_hauer_mapHeight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Map', array(
			'label' => esc_html__( 'Show Map', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionGoogleMaps',
			'settings' => 'blake_von_hauer_sh_Map',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_enableMapKey', array(
			'label' => esc_html__( 'Enable Map API Key', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionGoogleMaps',
			'settings' => 'blake_von_hauer_enableMapKey',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_mapAPI', array(
			'label' => esc_html__( 'API Key', 'blake-von-hauer' ),
			'description' => esc_html__( 'Only used if "Enable Map API Key" is checked.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionGoogleMaps',
			'settings' => 'blake_von_hauer_mapAPI',
			'type' => 'text',
		) );

		function blake_von_hauer_returnMapPageID( $input ) {

			if( is_numeric( $input ) ) {

				return intval( $input );

			}

		}
		/* */

		/* Translation */
		$wp_customize->add_control( 'blake_von_hauer_IgnorePOT', array(
			'label' => esc_html__( 'Ignore .pot file and use the translations below.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_IgnorePOT',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Lang', array(
			'label' => esc_html__( '13.1. Site Language', 'blake-von-hauer' ),
			'description' => esc_html__( 'Original: "', 'blake-von-hauer' ) . esc_html( get_bloginfo( 'language' ) ) . '"',
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Lang',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_ReadMore', array(
			'label' => esc_html__( '13.2. General', 'blake-von-hauer' ),
			'description' => esc_html__( 'Original: "/ READ MORE /"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_ReadMore',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_OlderPosts', array(
			'description' => esc_html__( 'Original: "OLDER POSTS"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_OlderPosts',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_NewerPosts', array(
			'description' => esc_html__( 'Original: "NEWER POSTS"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_NewerPosts',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_PrevPost', array(
			'description' => esc_html__( 'Original: "PREVIOUS POST"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_PrevPost',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_NextPost', array(
			'description' => esc_html__( 'Original: "NEXT POST"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_NextPost',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_TypeKeyword', array(
			'description' => esc_html__( 'Original: "TYPE KEYWORD TO SEARCH"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_TypeKeyword',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Views', array(
			'description' => esc_html__( 'Original: "VIEWS"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Views',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_AllByAuthor', array(
			'description' => esc_html__( 'Original: "VIEW ALL POSTS BY AUTHOR"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_AllByAuthor',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_AuthorWebsite', array(
			'description' => esc_html__( 'Original: "VISIT AUTHOR WEBSITE"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_AuthorWebsite',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_DontMiss', array(
			'description' => esc_html__( 'Original: "DON\'T MISS THIS ONE:"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_DontMiss',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Page', array(
			'description' => esc_html__( 'Original: "PAGE"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Page',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Sticky', array(
			'description' => esc_html__( 'Original: "STICKY"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Sticky',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_ViewAll', array(
			'description' => esc_html__( 'Original: "VIEW ALL"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_ViewAll',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_BackToTop', array(
			'description' => esc_html__( 'Original: "BACK TO TOP"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_BackToTop',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_404', array(
			'description' => esc_html__( 'Original: "PAGE NOT FOUND"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_404',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Nothing', array(
			'description' => esc_html__( 'Original: "NOTHING FOUND"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Nothing',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_SearchResults', array(
			'label' => esc_html__( '13.3. Archive Titles', 'blake-von-hauer' ),
			'description' => esc_html__( 'Original: "SEARCH RESULTS"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_SearchResults',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Tag', array(
			'description' => esc_html__( 'Original: "TAG"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Tag',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Category', array(
			'description' => esc_html__( 'Original: "CATEGORY"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Category',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Archives', array(
			'description' => esc_html__( 'Original: "ARCHIVES"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Archives',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Comment', array(
			'label' => esc_html__( '13.4. Post Comments', 'blake-von-hauer' ),
			'description' => esc_html__( 'Original: "Comment"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Comment',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Comments', array(
			'description' => esc_html__( 'Original: "Comments"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Comments',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Name', array(
			'description' => esc_html__( 'Original: "NAME"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Name',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Email', array(
			'description' => esc_html__( 'Original: "E-MAIL"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Email',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Website', array(
			'description' => esc_html__( 'Original: "WEBSITE"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Website',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_MustBeLogged', array(
			'description' => esc_html__( 'Original: "YOU MUST BE LOGGED IN TO POST A COMMENT"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_MustBeLogged',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_LoginToReply', array(
			'description' => esc_html__( 'Original: "LOG IN TO REPLY"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_LoginToReply',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Logged', array(
			'description' => esc_html__( 'Original: "LOGGED IN"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Logged',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_LogOut', array(
			'description' => esc_html__( 'Original: "LOG OUT"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_LogOut',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_LeaveReply', array(
			'description' => esc_html__( 'Original: "Leave a Reply"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_LeaveReply',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_CancelReply', array(
			'description' => esc_html__( 'Original: "CANCEL REPLY"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_CancelReply',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_PostComment', array(
			'description' => esc_html__( 'Original: "POST COMMENT"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_PostComment',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_At', array(
			'description' => esc_html__( 'Original: "AT"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_At',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Reply', array(
			'description' => esc_html__( 'Original: "REPLY"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Reply',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Edit', array(
			'description' => esc_html__( 'Original: "EDIT"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Edit',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Awaiting', array(
			'description' => esc_html__( 'Original: "Comment awaiting approval."', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Awaiting',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_tra_Cookie', array(
			'description' => esc_html__( 'Original: "Save my name, email, and website in this browser for the next time I comment"', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionTranslation',
			'settings' => 'blake_von_hauer_tra_Cookie',
			'type' => 'text',
		) );
		/* */

		/* Banner Management */
		$wp_customize->add_control( 'blake_von_hauer_opt_ResponsiveBannerHide', array(
			'label' => esc_html__( '14.0. Responsive Options', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_opt_ResponsiveBannerHide',
			'type' => 'radio',
			'choices' => array(
				'always' => 'Always Show',
				'480' => 'Hide at 480px',
				'640' => 'Hide at 640px',
				'800' => 'Hide at 800px',
				'960' => 'Hide at 960px'
			)
		) );
		$wp_customize->add_control( new blake_von_hauer_customTextAreaControl( $wp_customize, 'blake_von_hauer_text_Banner_1', array(
			'label' => esc_html__( '14.1. Banner 1', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_text_Banner_1',
			'type' => 'text',
		) ) );
		$wp_customize->add_control( new blake_von_hauer_BannerPlacement( $wp_customize, 'blake_von_hauer_opt_BannerPos_1', array(
			'label' => esc_html__( 'Choose a Position', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'description' => esc_html__( 'Choose the placement for "Banner 1"', 'blake-von-hauer' ),
			'settings' => 'blake_von_hauer_opt_BannerPos_1'
		) ) );
		$wp_customize->add_control( 'blake_von_hauer_opt_ResponsiveBanner_1', array(
			'label' => esc_html__( 'Responsive?', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_opt_ResponsiveBanner_1',
			'type' => 'radio',
			'choices' => array(
				'static' => 'Static',
				'responsive' => 'Responsive'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Banner_1_Archive', array(
			'label' => esc_html__( 'Show "Banner 1" on Archive Pages', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_sh_Banner_1_Archive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Banner_1_Post', array(
			'label' => esc_html__( 'Show "Banner 1" on Post Pages', 'blake-von-hauer' ),
			'description' => esc_html__( 'The checkboxes above are only used if "Below Header", "Above Upper Widgets" or "Below Upper Widgets" is selected.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_sh_Banner_1_Post',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new blake_von_hauer_customTextAreaControl( $wp_customize, 'blake_von_hauer_text_Banner_2', array(
			'label' => esc_html__( '14.2. Banner 2', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_text_Banner_2',
			'type' => 'text',
		) ) );
		$wp_customize->add_control( new blake_von_hauer_BannerPlacement( $wp_customize, 'blake_von_hauer_opt_BannerPos_2', array(
			'label' => esc_html__( 'Choose a Position', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'description' => esc_html__( 'Choose the placement for "Banner 2"', 'blake-von-hauer' ),
			'settings' => 'blake_von_hauer_opt_BannerPos_2'
		) ) );
		$wp_customize->add_control( 'blake_von_hauer_opt_ResponsiveBanner_2', array(
			'label' => esc_html__( 'Responsive?', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_opt_ResponsiveBanner_2',
			'type' => 'radio',
			'choices' => array(
				'static' => 'Static',
				'responsive' => 'Responsive'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Banner_2_Archive', array(
			'label' => esc_html__( 'Show "Banner 2" on Archive Pages', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_sh_Banner_2_Archive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Banner_2_Post', array(
			'label' => esc_html__( 'Show "Banner 2" on Post Pages', 'blake-von-hauer' ),
			'description' => esc_html__( 'The checkboxes above are only used if "Below Header", "Above Upper Widgets" or "Below Upper Widgets" is selected.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_sh_Banner_2_Post',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new blake_von_hauer_customTextAreaControl( $wp_customize, 'blake_von_hauer_text_Banner_3', array(
			'label' => esc_html__( '14.3. Banner 3', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_text_Banner_3',
			'type' => 'text',
		) ) );
		$wp_customize->add_control( new blake_von_hauer_BannerPlacement( $wp_customize, 'blake_von_hauer_opt_BannerPos_3', array(
			'label' => esc_html__( 'Choose a Position', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'description' => esc_html__( 'Choose the placement for "Banner 3"', 'blake-von-hauer' ),
			'settings' => 'blake_von_hauer_opt_BannerPos_3'
		) ) );
		$wp_customize->add_control( 'blake_von_hauer_opt_ResponsiveBanner_3', array(
			'label' => esc_html__( 'Responsive?', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_opt_ResponsiveBanner_3',
			'type' => 'radio',
			'choices' => array(
				'static' => 'Static',
				'responsive' => 'Responsive'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Banner_3_Archive', array(
			'label' => esc_html__( 'Show "Banner 3" on Archive Pages', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_sh_Banner_3_Archive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Banner_3_Post', array(
			'label' => esc_html__( 'Show "Banner 3" on Post Pages', 'blake-von-hauer' ),
			'description' => esc_html__( 'The checkboxes above are only used if "Below Header", "Above Upper Widgets" or "Below Upper Widgets" is selected.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_sh_Banner_3_Post',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new blake_von_hauer_customTextAreaControl( $wp_customize, 'blake_von_hauer_text_Banner_4', array(
			'label' => esc_html__( '14.4. Banner 4', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_text_Banner_4',
			'type' => 'text',
		) ) );
		$wp_customize->add_control( new blake_von_hauer_BannerPlacement( $wp_customize, 'blake_von_hauer_opt_BannerPos_4', array(
			'label' => esc_html__( 'Choose a Position', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'description' => esc_html__( 'Choose the placement for "Banner 4"', 'blake-von-hauer' ),
			'settings' => 'blake_von_hauer_opt_BannerPos_4'
		) ) );
		$wp_customize->add_control( 'blake_von_hauer_opt_ResponsiveBanner_4', array(
			'label' => esc_html__( 'Responsive?', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_opt_ResponsiveBanner_4',
			'type' => 'radio',
			'choices' => array(
				'static' => 'Static',
				'responsive' => 'Responsive'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Banner_4_Archive', array(
			'label' => esc_html__( 'Show "Banner 4" on Archive Pages', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_sh_Banner_4_Archive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Banner_4_Post', array(
			'label' => esc_html__( 'Show "Banner 4" on Post Pages', 'blake-von-hauer' ),
			'description' => esc_html__( 'The checkboxes above are only used if "Below Header", "Above Upper Widgets" or "Below Upper Widgets" is selected.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_sh_Banner_4_Post',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new blake_von_hauer_customTextAreaControl( $wp_customize, 'blake_von_hauer_text_Banner_5', array(
			'label' => esc_html__( '14.5. Banner 5', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_text_Banner_5',
			'type' => 'text',
		) ) );
		$wp_customize->add_control( new blake_von_hauer_BannerPlacement( $wp_customize, 'blake_von_hauer_opt_BannerPos_5', array(
			'label' => esc_html__( 'Choose a Position', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'description' => esc_html__( 'Choose the placement for "Banner 5"', 'blake-von-hauer' ),
			'settings' => 'blake_von_hauer_opt_BannerPos_5'
		) ) );
		$wp_customize->add_control( 'blake_von_hauer_opt_ResponsiveBanner_5', array(
			'label' => esc_html__( 'Responsive?', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_opt_ResponsiveBanner_5',
			'type' => 'radio',
			'choices' => array(
				'static' => 'Static',
				'responsive' => 'Responsive'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Banner_5_Archive', array(
			'label' => esc_html__( 'Show "Banner 5" on Archive Pages', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_sh_Banner_5_Archive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Banner_5_Post', array(
			'label' => esc_html__( 'Show "Banner 5" on Post Pages', 'blake-von-hauer' ),
			'description' => esc_html__( 'The checkboxes above are only used if "Below Header", "Above Upper Widgets" or "Below Upper Widgets" is selected.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_sh_Banner_5_Post',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( new blake_von_hauer_customTextAreaControl( $wp_customize, 'blake_von_hauer_text_Banner_Header', array(
			'label' => esc_html__( '14.6. Header Banner', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_text_Banner_Header',
			'type' => 'text',
		) ) );
		$wp_customize->add_control( 'blake_von_hauer_sh_Banner_Header', array(
			'label' => esc_html__( 'Show Header Banner', 'blake-von-hauer' ),
			'description' => esc_html__( 'Note: 4. Header > 4.7. Logo Position must be "Top" or "Bottom".', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionBanner',
			'settings' => 'blake_von_hauer_sh_Banner_Header',
			'type' => 'checkbox'
		) );
		/* */

		/* Slider Settings */
		$wp_customize->add_control( 'blake_von_hauer_explanation_12', array(
			'label' => esc_html__( 'Important Note', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'When you upload an image into your media library, it gets the sizes below. If you change these settings AFTER you uploaded an image, the image will not change its sizes. So, you have to re-upload it or use a plugin like <a href="https://wordpress.org/plugins/regenerate-thumbnails/" target="_blank">Regenerate Thumbnails</a> which is a very good practice.', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_explanation_12',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_sliderWidth', array(
			'label' => esc_html__( '15.1. Slide Image Width', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'Theme default: "1160"<br>Since the slider is responsive, display results may seem different. If you want to use "Fullwidth" option for instance, to set it 2560 and upload big images make sense.<br>Works for only new added images.', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_sliderWidth',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_sliderHeight', array(
			'label' => esc_html__( '15.2. Slide Image Height', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'Theme default: "500"<br>This value is fixed, not responsive.<br>Works for only new added images.', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_sliderHeight',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_SliderPosition', array(
			'label' => esc_html__( '15.3. Slider Position & View', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'When you choose "Fullwidth" for slider, it makes the container fullwidth, not the image. So, you should try to upload a bigger image or use a plugin like <a href="https://wordpress.org/plugins/regenerate-thumbnails/" target="_blank">Regenerate Thumbnails</a> to resize the uploaded images if they are already big enough.', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_opt_SliderPosition',
			'type' => 'radio',
			'choices' => array(
				'full' => 'Fullwidth',
				'cover' => 'Cover',
				'among' => 'Among the Posts (Blog Homepage Only)'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_rng_Sli_Box', array(
			'type'        => 'range',
			'section'     => 'blake_von_hauer_sectionSlider',
			'label'       => 'Slider Box Opacity',

			'input_attrs' => array(
				'min'   => 0,
				'max'   => 100,
				'step'  => 10
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sliderShortcode', array(
			'label' => esc_html__( '15.4. Shortcode', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'Example usages:<br>Old Slider:<br>[bvhslider group="your_group"]<br>New Slider:<br>[new_bvhslider group="your_group"]', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_sliderShortcode',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_explanation_8', array(
			'label' => esc_html__( '15.5. Blog Posts in Slider', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_explanation_8',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_bpts', array(
			'label' => esc_html__( 'Show Blog Posts in Slider', 'blake-von-hauer' ),
			'description' => esc_html__( 'Disables the shortcode if checked.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_bpts',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sliderCategory', array(
			'description' => esc_html__( 'Write a category slug to show the category posts in slider. Leave blank to show all posts. Only used if "Show Blog Posts in Slider" is checked.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_sliderCategory',
			'type' => 'text',
		) );
		$wp_customize->add_control( 'blake_von_hauer_bptsNumber', array(
			'description' => wp_kses( __( 'Number of the posts to show in slider:<br>Only used if "Show Blog Posts in Slider" is checked.', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_bptsNumber',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_bptsExclude', array(
			'label' => esc_html__( 'Exclude the Slider Posts From Feed', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_bptsExclude',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_SliderHomeView', array(
			'label' => esc_html__( '15.6. Blog Homepage View Options', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_opt_SliderHomeView',
			'type' => 'radio',
			'choices' => array(
				'home-all' => 'During Pagination',
				'home-front' => 'Only on the First Page of Pagination',
				'home-hide' => 'Hide on Blog Homepage'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sliderHideMobile', array(
			'label' => esc_html__( '15.7. Mobile Settings', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_sliderHideMobile',
			'type' => 'radio',
			'choices' => array(
				'always' => 'Always Show',
				'320' => 'Hide at 320px',
				'480' => 'Hide at 480px',
				'640' => 'Hide at 640px'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_bxControls_Main', array(
			'label' => esc_html__( '15.8. Control Settings', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_opt_bxControls_Main',
			'type' => 'radio',
			'choices' => array(
				'arrow' => 'Show Prev/Next Arrows',
				'bullet' => 'Show Pager Bullets',
				'both' => 'Show Both',
				'none' => 'None'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_opt_bxControls_Colors', array(
			'description' => esc_html__( 'Choose Arrow/Bullet Color', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_opt_bxControls_Colors',
			'type' => 'radio',
			'choices' => array(
				'primary' => 'Primary Color',
				'white' => 'White',
				'black' => 'Black'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_sliderPause', array(
			'label' => esc_html__( '15.9. Autoplay Duration', 'blake-von-hauer' ),
			'description' => wp_kses( __( 'Theme default: "4000"<br>Only used if "Autoplay Slides" is checked.', 'blake-von-hauer' ), $blake_von_hauer_allowed_html ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_sliderPause',
			'type' => 'number',
			'input_attrs' => array(
				'style' => 'width: 65px;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_bxAuto_Main', array(
			'label' => esc_html__( 'Autoplay Slides', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_bxAuto_Main',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sliderMode', array(
			'label' => esc_html__( '15.10. Transition Effect', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_sliderMode',
			'type' => 'radio',
			'choices' => array(
				'horizontal' => 'Horizontal',
				'fade' => 'Fade'
			)
		) );
		$wp_customize->add_control( 'blake_von_hauer_explanation_9', array(
			'label' => esc_html__( '15.11. Show/Hide & Other Options', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_explanation_9',
			'input_attrs' => array(
				'style' => 'display: none;',
			),
		) );
		$wp_customize->add_control( 'blake_von_hauer_bptsDate', array(
			'label' => esc_html__( 'Show Post Dates', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_bptsDate',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_bptsAuthor', array(
			'label' => esc_html__( 'Show Post Author', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_bptsAuthor',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_bptsComment', array(
			'label' => esc_html__( 'Show Post Comments Icon', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_bptsComment',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_bptsCategories', array(
			'label' => esc_html__( 'Show Categories', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_bptsCategories',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_bptsCaption', array(
			'label' => esc_html__( 'Show Excerpt', 'blake-von-hauer' ),

			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_bptsCaption',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_SliderArchive', array(
			'label' => esc_html__( 'Show Slider on Archive Pages', 'blake-von-hauer' ),
			'description' => esc_html__( '"15.3. Slider Position & View" must be "Fullwidth" or "Cover".', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_sh_SliderArchive',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_SliderPost', array(
			'label' => esc_html__( 'Show Slider on Post Pages', 'blake-von-hauer' ),
			'description' => esc_html__( '"15.3. Slider Position & View" must be "Fullwidth" or "Cover".', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_sh_SliderPost',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sh_SliderPage', array(
			'label' => esc_html__( 'Show Slider on Pages', 'blake-von-hauer' ),
			'description' => esc_html__( '"15.3. Slider Position & View" must be "Fullwidth" or "Cover".', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_sh_SliderPage',
			'type' => 'checkbox'
		) );
		$wp_customize->add_control( 'blake_von_hauer_sliderInfinite', array(
			'label' => esc_html__( 'Infinite Loop', 'blake-von-hauer' ),
			'description' => esc_html__( 'If checked, clicking "Next" while on the last slide will transition to the first slide and vice-versa.', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_sliderInfinite',
			'type' => 'checkbox',
		) );
		$wp_customize->add_control( 'blake_von_hauer_sliderRandom', array(
			'label' => esc_html__( 'Start with a Random Slide', 'blake-von-hauer' ),
			'section' => 'blake_von_hauer_sectionSlider',
			'settings' => 'blake_von_hauer_sliderRandom',
			'type' => 'checkbox',
		) );
		/* */

		/* Custom CSS */
		$wp_customize->add_control( new blake_von_hauer_customTextAreaControl( $wp_customize, 'blake_von_hauer_text_CSS', array(
			'section' => 'blake_von_hauer_sectionCSS',
			'settings' => 'blake_von_hauer_text_CSS',
			'type' => 'text',
		) ) );
		/* */

	}
}
add_action( 'customize_register', 'blake_von_hauer_customizeAppearance' );
?>
